# django-gesha ☕

[![Test](https://github.com/ely-as/django-gesha/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/ely-as/django-gesha/actions/workflows/test.yml)
![Version](https://img.shields.io/pypi/v/django-gesha)
![Python](https://img.shields.io/pypi/pyversions/django-gesha)
![Django](https://img.shields.io/pypi/djversions/django-gesha)

JavaScript utilities for [Django](https://www.djangoproject.com/) projects.

**Current features:**

  - Easily add JavaScript context in class-based views and access it via a JavaScript API.

Many more [features are planned](https://github.com/ely-as/django-gesha/labels/feature) ✍️.
